local AceGUI = LibStub("AceGUI-3.0")

local debuffsPick, debuffName, debuffCount;

function MorthalinRaidTools:ConstructDebuffsSettings()
	self.ui.debuffsSetting = AceGUI:Create("Frame");
	self.ui.debuffsSetting:SetTitle("Debuffs settings");
	self.ui.debuffsSetting:SetStatusText("");
	self.ui.debuffsSetting:SetLayout("Flow");
	self.ui.debuffsSetting:SetWidth(445);
	self.ui.debuffsSetting:SetHeight(195);
	self.ui.debuffsSetting:EnableResize(false);
	self.ui.debuffsSetting.frame:EnableMouse(true);
	self.ui.debuffsSetting.frame:SetUserPlaced(true);
	
	debuffsPick = AceGUI:Create("Dropdown");
	debuffsPick:SetLabel("Buffs");
	debuffsPick:SetWidth(360);
	debuffsPick:SetCallback("OnValueChanged", function(obj, func, value) MorthalinRaidTools:DebuffPicked(); end);
	self.ui.debuffsSetting:AddChild(debuffsPick);
	
	local addDebuff = AceGUI:Create("Icon");
	addDebuff:SetImage("Interface\\Icons\\spell_chargepositive");
	addDebuff:SetWidth(20);
	addDebuff:SetHeight(20);
	addDebuff:SetImageSize(17,17);
	addDebuff:SetCallback("OnClick", function() MorthalinRaidTools:AddDebuff() end);
	self.ui.debuffsSetting:AddChild(addDebuff);
	
	local removeDebuff = AceGUI:Create("Icon");
	removeDebuff:SetImage("Interface\\Icons\\spell_chargenegative");
	removeDebuff:SetWidth(20);
	removeDebuff:SetHeight(20);
	removeDebuff:SetImageSize(15,15);
	removeDebuff:SetCallback("OnClick", function() MorthalinRaidTools:RemoveDebuff(); end);
	self.ui.debuffsSetting:AddChild(removeDebuff);
	
	debuffName = AceGUI:Create("EditBox");
	debuffName:SetLabel("Buff name");
	debuffName:SetWidth(134);
	debuffName:SetCallback("OnEnterPressed", function(widget, event, text) MorthalinRaidTools:SetDebuffName(text); end);
	self.ui.debuffsSetting:AddChild(debuffName);
	
	debuffCount = AceGUI:Create("EditBox");
	debuffCount:SetLabel("Stacks");
	debuffCount:SetWidth(133);
	debuffCount:SetCallback("OnEnterPressed", function(widget, event, text) MorthalinRaidTools:SetDebuffCounts(text); end);
	self.ui.debuffsSetting:AddChild(debuffCount);
	
	local btnStatistics = AceGUI:Create("Button");
	btnStatistics:SetText("Broadcast all");
	btnStatistics:SetWidth(200);
	btnStatistics:SetCallback("OnClick", function() MorthalinRaidTools:SendDebuffSettings(); end);
	self.ui.debuffsSetting:AddChild(btnStatistics);
	
	local btnStatistics = AceGUI:Create("Button");
	btnStatistics:SetText("Broadcast selected");
	btnStatistics:SetWidth(200);
	btnStatistics:SetCallback("OnClick", function() if(debuffsPick:GetValue() ~= nil and debuffsPick.list[debuffsPick:GetValue()] ~= nil) then MorthalinRaidTools:SendDebuffSettingsSelected(debuffsPick.list[debuffsPick:GetValue()]); end end);
	self.ui.debuffsSetting:AddChild(btnStatistics);
	
	MorthalinRaidTools:LoadDebuffs();
end

function MorthalinRaidTools:ShowDebuffsSettings()
	if(self.ui.debuffsSetting:IsVisible() == false) then
		self.ui.debuffsSetting:Show();
		iconEdit.frame:Hide();
		iconPic.frame:Hide();
	end
end

function MorthalinRaidTools:HideDebuffsSettings()
	if(self.ui.debuffsSetting:IsVisible()) then
		self.ui.debuffsSetting:Hide();
	end
end

function MorthalinRaidTools:LoadDebuffs(index)
	local debuffsSort = {};
	for name, data in pairs(MorthalinRaidTools.db.global.timedAuras) do
		table.insert(debuffsSort, name);
	end
	local function sortNames(a, b)
		return a < b;
	end
	table.sort(debuffsSort, sortNames);
	debuffsPick:SetValue(nil);
	debuffsPick:SetList({});
	for i = 1, #debuffsSort do
		debuffsPick:AddItem(i, debuffsSort[i]);
	end
	if(index == nil) then
		index = 1;
	end
	if(#debuffsSort >= index) then
		debuffsPick:SetValue(index);
	end
	MorthalinRaidTools:DebuffPicked();
end

function MorthalinRaidTools:AddDebuff()
	MorthalinRaidTools.db.global.timedAuras["New buff"] = {count = {1}};
	debuffsPick:AddItem(#debuffsPick.list, "New buff");
	debuffName:SetText("New buff");
	debuffCount:SetText("1");
	debuffsPick:SetValue(#debuffsPick.list);
end

function MorthalinRaidTools:SetDebuffName(text)
	self.db.global.timedAuras[text] = self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]];
	self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]] = nil;
	MorthalinRaidTools:LoadBuffs(debuffsPick:GetValue());
end

function MorthalinRaidTools:SetDebuffCounts(text)
	local array = {};
	local temp = "";
	for num in string.gmatch(text, "%d+") do
		temp = temp .. num .. ",";
		table.insert(array, tonumber(num));
	end
	temp = temp:sub(1, -2);
	if(array ~= nil and #array > 0) then
		local function sortStacks(a, b)
			return a < b;
		end
		table.sort(array, sortStacks);
		self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count = array;
		debuffCount:SetText(temp);
	else
		local countText = "";
		for i = 1, #self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count do
			if(countText == "") then
				countText = tostring(self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count[i]);
			else
				countText = countText .. "," .. self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count[i];
			end
		end
		debuffCount:SetText(tostring(countText));
	end
end

function MorthalinRaidTools:RemoveDebuff()
	self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]] = nil;
	MorthalinRaidTools:LoadBuffs();
end

function MorthalinRaidTools:DebuffPicked()
	if(debuffsPick:GetValue() ~= nil) then
		local countText = "";
		debuffName:SetText(debuffsPick.list[debuffsPick:GetValue()]);
		for i = 1, #self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count do
			if(countText == "") then
				countText = tostring(self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count[i]);
			else
				countText = countText .. "," .. self.db.global.timedAuras[debuffsPick.list[debuffsPick:GetValue()]].count[i];
			end
		end
		debuffCount:SetText(tostring(countText));
	else
		debuffName:SetText("");
		debuffCount:SetText("");
	end
end
